@@ -525,6 +525,7 @@ fixed.effects.summary.clme <- function( object, ...){
 }
 
 
+#' Extract fixed effects
 #' 
 #' @rdname fixef.clme
 #' 
@@ -536,14 +537,9 @@ fixed.effects.clme <- function( object , ... ){
   fixef.clme( object, ... )
 }
 
-#' @rdname fixef.clme
-#' @method coefficients clme
-#' @export
-#' 
-fixed.effects.clme <- function( object , ... ){
-  fixef.clme( object, ... )
-}
 
+#' Extract fixed effects
+#' 
 #' @rdname fixef.clme
 #' @method coefficients clme
 #' @export
@@ -552,6 +548,8 @@ coefficients.clme <- function( object, ... ){
   fixef.clme( object, ... )
 }
 
+#' Extract fixed effects
+#' 
 #' @rdname fixef.clme
 #' @method coef clme
 #' @export
@@ -560,6 +558,8 @@ coef.clme <- function( object, ... ){
   fixef.clme( object, ... )
 }
 
+#' Extract fixed effects
+#' 
 #' @rdname fixef.clme
 #' @method coefficients summary.clme
 #' @export
@@ -569,6 +569,8 @@ coefficients.summary.clme <- function( object, ... ){
   fixef.clme( object, ... )
 }
 
+#' Extract fixed effects
+#' 
 #' @rdname fixef.clme
 #' @method coef summary.clme
 #' @export
@@ -1009,6 +1011,7 @@ random.effects.summary.clme <- function( object, ...){
 }
 
 
+#' Extract random effects
 #' 
 #' @rdname ranef.clme
 #' @importFrom nlme random.effects
@@ -1081,21 +1084,6 @@ residuals.summary.clme <- function( object, type="FM", ... ){
 
 
 
-#' Residual variance components
-#' 
-#' @param object object of class \code{\link{clme}}.
-#' @param ... space for additional arguments
-#' 
-#' @description
-#' Extract residual variance components for objects of class \code{clme}.
-#'
-#' @export
-#' 
-sigma <- function( object, ...){
-  UseMethod("sigma")
-}
-
-
 
 #' Residual variance components
 #'
@@ -1119,9 +1107,10 @@ sigma <- function( object, ...){
 #' cons <- list(order = "simple", decreasing = FALSE, node = 1 )
 #' clme.out <- clme(mcv ~ time + temp + sex + (1|id), data = rat.blood , 
 #'                  constraints = cons, seed = 42, nsim = 0)
-#'                  
+#'          
 #' sigma( clme.out )
 #' 
+#' @importFrom lme4 sigma
 #' @method sigma clme
 #' @export
 #' 
@@ -1162,16 +1151,16 @@ sigma.summary.clme <- function( object, ...){
 }
 
 
-
 #' Variance components
 #' 
-#' @param object object from which to extract variance components
-#' @param ... space for additional arguments.
-#' 
+#' @param x object of class \code{\link{summary.clme}}.
+#' @param sigma (unused at present).
+#' @param rdig number of digits to round to (unused at present).
+#'  
 #' @rdname VarCorr
 #' @export
 #' 
-VarCorr <- function( object, ...){ UseMethod("VarCorr") }
+VarCorr <- function( x, sigma, rdig ){ UseMethod("VarCorr") }
 
 
 #' Variance components
@@ -1179,12 +1168,14 @@ VarCorr <- function( object, ...){ UseMethod("VarCorr") }
 #' @rdname VarCorr
 #' @export
 #' 
-VarCorr.summary.clme <- function( object, ...){
-  class(object) <- "clme"
-  VarCorr(object, ...)
+VarCorr.summary.clme <- function( x, sigma, rdig ){
+  class(x) <- "clme"
+  VarCorr(x, sigma=1, rdig=4)
 }
 
 
+
+
 #' Variance components.
 #'
 #' @description
@@ -1209,22 +1200,23 @@ VarCorr.summary.clme <- function( object, ...){
 #' VarCorr( clme.out )
 #' 
 #' 
-#' @importFrom lme4 VarCorr
+#' 
 #' @method VarCorr clme
 #' @export
 #' 
-VarCorr.clme <- function(object, ...){
+VarCorr.clme <- function(x, sigma, rdig ){
+  # @importFrom lme4 VarCorr
   ## Print out variances or SDs
   ## Defines tiny class "varcorr_clme" to handle printing
   ## using the method: print.varcorr_clme
-  if( !is.clme(object) ){
-    stop("'object' is not of class clme")
+  if( !is.clme(x) ){
+    stop("'x' is not of class clme")
   } else{
-    varcomps <- matrix( c(object$tsq, object$ssq ), ncol=1 )
-    rnames   <- c( "Source", names(object$tsq), names(object$ssq) )
+    varcomps <- matrix( sqrt(c(x$tsq, x$ssq )), ncol=1 )
+    rnames   <- c( "Source", names(x$tsq), names(x$ssq) )
     rownames(varcomps) <- rnames[-1]
-    colnames(varcomps) <- "Variance"
-    class(varcomps)    <- "varcorr_clme"
+    colnames(varcomps) <- "Std. Error"
+    #class(varcomps)    <- "varcorr_clme"
     return( varcomps )
   }
 }
@@ -1261,16 +1253,18 @@ VarCorr.clme <- function(object, ...){
 #' @exportMethod print varcorr_clme
 #' 
 print.varcorr_clme <- function(object, rdig=5, ...){
-
+  
   rnames   <- c( "Source", rownames( object ) )
   rnames   <- str_pad(rnames, width=max(nchar(rnames)), side = "right", pad = " ")
   vars     <- format( object , digits=rdig )
-    
+
   cat( rnames[1], "\t" , "Variance" )
   for( ii in 1:length(vars) ){
     cat( "\n", rnames[ii+1], "\t" , vars[ii] )
   }
   
+  return(NULL)
+  
 }
 
 
